pub trait ObservableFeatures {
type Feature;
// Required methods
fn present_features(&self) -> impl Iterator<Item = &Self::Feature>;
fn excluded_features(&self) -> impl Iterator<Item = &Self::Feature>;
// Provided methods
fn present_feature_count(&self) -> usize { ... }
fn excluded_feature_count(&self) -> usize { ... }
}Expand description
Common functionalities for containers of Observable features.
Required Associated Types
Required Methods
Sourcefn present_features(&self) -> impl Iterator<Item = &Self::Feature>
fn present_features(&self) -> impl Iterator<Item = &Self::Feature>
Get an iterator over features that were observed in the investigated item.
Sourcefn excluded_features(&self) -> impl Iterator<Item = &Self::Feature>
fn excluded_features(&self) -> impl Iterator<Item = &Self::Feature>
Get an iterator over features whose presence was specifically excluded in the investigated item.
Provided Methods
Sourcefn present_feature_count(&self) -> usize
fn present_feature_count(&self) -> usize
Get the number of observed features.
Sourcefn excluded_feature_count(&self) -> usize
fn excluded_feature_count(&self) -> usize
Get the number of features whose presence was specifically excluded.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".